summaryrefslogtreecommitdiffstats
path: root/kmail/networkaccount.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/networkaccount.cpp')
-rw-r--r--kmail/networkaccount.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/kmail/networkaccount.cpp b/kmail/networkaccount.cpp
index 5e4f5b5e..7f4c53b3 100644
--- a/kmail/networkaccount.cpp
+++ b/kmail/networkaccount.cpp
@@ -39,7 +39,7 @@
#include <kdebug.h>
#include <tdewallet.h>
using TDEIO::MetaData;
-using KWallet::Wallet;
+using TDEWallet::Wallet;
#include <climits>
@@ -162,7 +162,7 @@ namespace KMail {
if ( !encpasswd.isEmpty() ) {
setPasswd( decryptStr( encpasswd ), true );
// migrate to KWallet if available
if ( Wallet::isEnabled() ) {
config.deleteEntry( "pass" );
config.deleteEntry( "passwd" );
@@ -217,15 +217,15 @@ namespace KMail {
// if wallet is not available, write to config file, since the account
// manager deletes this group, we need to write it always
if ( !passwdStored && ( mStorePasswdInConfig || KMessageBox::warningYesNo( 0,
- i18n("KWallet is not available. It is strongly recommended to use "
- "KWallet for managing your passwords.\n"
+ i18n("TDEWallet is not available. It is strongly recommended to use "
+ "TDEWallet for managing your passwords.\n"
"However, KMail can store the password in its configuration "
"file instead. The password is stored in an obfuscated format, "
"but should not be considered secure from decryption efforts "
"if access to the configuration file is obtained.\n"
"Do you want to store the password for account '%1' in the "
"configuration file?").arg( name() ),
- i18n("KWallet Not Available"),
+ i18n("TDEWallet Not Available"),
KGuiItem( i18n("Store Password") ),
KGuiItem( i18n("Do Not Store Password") ) )
== KMessageBox::Yes ) ) {
@@ -162,7 +162,7 @@ namespace KMail {
if ( !encpasswd.isEmpty() ) {
setPasswd( decryptStr( encpasswd ), true );
- // migrate to KWallet if available
+ // migrate to TDEWallet if available
if ( Wallet::isEnabled() ) {
config.deleteEntry( "pass" );